@@ -22,15 +22,21 @@ for theme in "${_THEME_VARIANTS[@]}"; do
   rm -rf "${THEME_NAME}${theme}.tar.xz"
 done
 
+rm -rf "01-${THEME_NAME}.tar.xz"
+
 for theme in "${_THEME_VARIANTS[@]}"; do
-  tar -Jcvf "${THEME_NAME}${theme}.tar.xz" "${THEME_NAME}${theme}"{'','-light','-dark'}
+  tar -Jcvf "${THEME_NAME}${theme}.tar.xz" "${THEME_NAME}${theme}"{'','-light','-dark'} ."${THEME_NAME}"{'','-light','-dark'}-base
 done
+
+mv "${THEME_NAME}.tar.xz" "01-${THEME_NAME}.tar.xz"
 }
 
 Clear_theme() {
 for theme in "${_THEME_VARIANTS[@]}"; do
   [[ -d "${THEME_NAME}${theme}" ]] && rm -rf "${THEME_NAME}${theme}"{'','-light','-dark'}
 done
+
+rm -rf ."${THEME_NAME}"{'','-light','-dark'}-base
 }
 
 cd .. && ./install.sh -d $THEME_DIR -a
